@@ -6,12 +6,15 @@
  * @package PhpMyAdmin
  */
 
+use PhpMyAdmin\Config\PageSettings;
+use PhpMyAdmin\Display\Import;
+use PhpMyAdmin\Response;
+
 require_once 'libraries/common.inc.php';
-require_once 'libraries/config/page_settings.class.php';
 
-PMA_PageSettings::showGroup('Import');
+PageSettings::showGroup('Import');
 
-$response = PMA_Response::getInstance();
+$response = Response::getInstance();
 $header   = $response->getHeader();
 $scripts  = $header->getScripts();
 $scripts->addFile('import.js');
@@ -31,12 +34,11 @@ list(
     $tooltip_truename,
     $tooltip_aliasname,
     $pos
-) = PMA_Util::getDbInfo($db, isset($sub_part) ? $sub_part : '');
+) = PhpMyAdmin\Util::getDbInfo($db, isset($sub_part) ? $sub_part : '');
 
-require 'libraries/display_import.lib.php';
-$response = PMA_Response::getInstance();
+$response = Response::getInstance();
 $response->addHTML(
-    PMA_getImportDisplay(
+    Import::get(
         'database', $db, $table, $max_upload_size
     )
 );
