@@ -13,8 +13,7 @@
  *
  * @param index_choice index choice
  */
-function PMA_getIndexArray(index_choice)
-{
+function PMA_getIndexArray (index_choice) {
     var source_array = null;
 
     switch (index_choice.toLowerCase()) {
@@ -43,8 +42,7 @@ function PMA_getIndexArray(index_choice)
  * Hides/shows the inputs and submits appropriately depending
  * on whether the index type chosen is 'SPATIAL' or not.
  */
-function checkIndexType()
-{
+function checkIndexType () {
     /**
      * @var Object Dropdown to select the index choice.
      */
@@ -70,7 +68,7 @@ function checkIndexType()
      */
     var $add_more = $('#index_frm').find('.add_more');
 
-    if ($select_index_choice.val() == 'SPATIAL') {
+    if ($select_index_choice.val() === 'SPATIAL') {
         // Disable and hide the size column
         $size_header.hide();
         $size_inputs.each(function () {
@@ -114,11 +112,11 @@ function checkIndexType()
         $add_more.show();
     }
 
-    if ($select_index_choice.val() == 'SPATIAL' ||
-            $select_index_choice.val() == 'FULLTEXT') {
+    if ($select_index_choice.val() === 'SPATIAL' ||
+            $select_index_choice.val() === 'FULLTEXT') {
         $select_index_type.val('').prop('disabled', true);
     } else {
-        $select_index_type.prop('disabled', false)
+        $select_index_type.prop('disabled', false);
     }
 }
 
@@ -130,9 +128,8 @@ function checkIndexType()
  *
  * @return void
  */
-function PMA_setIndexFormParameters(source_array, index_choice)
-{
-    if (index_choice == 'index') {
+function PMA_setIndexFormParameters (source_array, index_choice) {
+    if (index_choice === 'index') {
         $('input[name="indexes"]').val(JSON.stringify(source_array));
     } else {
         $('input[name="' + index_choice + '_indexes"]').val(JSON.stringify(source_array));
@@ -146,22 +143,21 @@ function PMA_setIndexFormParameters(source_array, index_choice)
  *
  * @return void
  */
-function PMA_removeColumnFromIndex(col_index)
-{
+function PMA_removeColumnFromIndex (col_index) {
     // Get previous index details.
     var previous_index = $('select[name="field_key[' + col_index + ']"]')
         .attr('data-index');
     if (previous_index.length) {
         previous_index = previous_index.split(',');
         var source_array = PMA_getIndexArray(previous_index[0]);
-        if (source_array == null) {
+        if (source_array === null) {
             return;
         }
 
         // Remove column from index array.
         var source_length = source_array[previous_index[1]].columns.length;
-        for (var i=0; i<source_length; i++) {
-            if (source_array[previous_index[1]].columns[i].col_index == col_index) {
+        for (var i = 0; i < source_length; i++) {
+            if (source_array[previous_index[1]].columns[i].col_index === col_index) {
                 source_array[previous_index[1]].columns.splice(i, 1);
             }
         }
@@ -188,8 +184,7 @@ function PMA_removeColumnFromIndex(col_index)
  *
  * @return void
  */
-function PMA_addColumnToIndex(source_array, array_index, index_choice, col_index)
-{
+function PMA_addColumnToIndex (source_array, array_index, index_choice, col_index) {
     if (col_index >= 0) {
         // Remove column from other indexes (if any).
         PMA_removeColumnFromIndex(col_index);
@@ -223,7 +218,7 @@ function PMA_addColumnToIndex(source_array, array_index, index_choice, col_index
 
     // Display index name (or column list)
     var displayName = index_name;
-    if (displayName == '') {
+    if (displayName === '') {
         var columnNames = [];
         $.each(columns, function () {
             columnNames.push($('input[name="field_name[' +  this.col_index + ']"]').val());
@@ -233,7 +228,7 @@ function PMA_addColumnToIndex(source_array, array_index, index_choice, col_index
     $.each(columns, function () {
         var id = 'index_name_' + this.col_index + '_8';
         var $name = $('#' + id);
-        if ($name.length == 0) {
+        if ($name.length === 0) {
             $name = $('<a id="' + id + '" href="#" class="ajax show_index_dialog"></a>');
             $name.insertAfter($('select[name="field_key[' + this.col_index + ']"]'));
         }
@@ -257,8 +252,7 @@ function PMA_addColumnToIndex(source_array, array_index, index_choice, col_index
  *
  * @return jQuery Object
  */
-function PMA_getCompositeIndexList(source_array, col_index)
-{
+function PMA_getCompositeIndexList (source_array, col_index) {
     // Remove any previous list.
     if ($('#composite_index_list').length) {
         $('#composite_index_list').remove();
@@ -274,15 +268,15 @@ function PMA_getCompositeIndexList(source_array, col_index)
     // Add each column to list available for composite index.
     var source_length = source_array.length;
     var already_present = false;
-    for (var i=0; i<source_length; i++) {
+    for (var i = 0; i < source_length; i++) {
         var sub_array_len = source_array[i].columns.length;
         var column_names = [];
-        for (var j=0; j<sub_array_len; j++) {
+        for (var j = 0; j < sub_array_len; j++) {
             column_names.push(
                 $('input[name="field_name[' + source_array[i].columns[j].col_index + ']"]').val()
             );
 
-            if (col_index == source_array[i].columns[j].col_index) {
+            if (col_index === source_array[i].columns[j].col_index) {
                 already_present = true;
             }
         }
@@ -312,14 +306,12 @@ function PMA_getCompositeIndexList(source_array, col_index)
  *
  * @return void
  */
-function PMA_showAddIndexDialog(source_array, array_index, target_columns, col_index, index)
-{
+function PMA_showAddIndexDialog (source_array, array_index, target_columns, col_index, index) {
     // Prepare post-data.
     var $table = $('input[name="table"]');
     var table = $table.length > 0 ? $table.val() : '';
     var post_data = {
         server: PMA_commonParams.get('server'),
-        token: PMA_commonParams.get('token'),
         db: $('input[name="db"]').val(),
         table: table,
         ajax_request: 1,
@@ -328,7 +320,7 @@ function PMA_showAddIndexDialog(source_array, array_index, target_columns, col_i
     };
 
     var columns = {};
-    for (var i=0; i<target_columns.length; i++) {
+    for (var i = 0; i < target_columns.length; i++) {
         var column_name = $('input[name="field_name[' + target_columns[i] + ']"]').val();
         var column_type = $('select[name="field_type[' + target_columns[i] + ']"]').val().toLowerCase();
         columns[column_name] = [column_type, target_columns[i]];
@@ -378,41 +370,41 @@ function PMA_showAddIndexDialog(source_array, array_index, target_columns, col_i
         $(this).dialog('close');
     };
     var $msgbox = PMA_ajaxShowMessage();
-    $.post("tbl_indexes.php", post_data, function (data) {
+    $.post('tbl_indexes.php', post_data, function (data) {
         if (data.success === false) {
-            //in the case of an error, show the error message returned.
+            // in the case of an error, show the error message returned.
             PMA_ajaxShowMessage(data.error, false);
         } else {
             PMA_ajaxRemoveMessage($msgbox);
             // Show dialog if the request was successful
             var $div = $('<div/>');
             $div
-            .append(data.message)
-            .dialog({
-                title: PMA_messages.strAddIndex,
-                width: 450,
-                minHeight: 250,
-                open: function () {
-                    checkIndexName("index_frm");
-                    PMA_showHints($div);
-                    PMA_init_slider();
-                    $('#index_columns').find('td').each(function () {
-                        $(this).css("width", $(this).width() + 'px');
-                    });
-                    $('#index_columns').find('tbody').sortable({
-                        axis: 'y',
-                        containment: $("#index_columns").find("tbody"),
-                        tolerance: 'pointer'
-                    });
-                    // We dont need the slider at this moment.
-                    $(this).find('fieldset.tblFooters').remove();
-                },
-                modal: true,
-                buttons: button_options,
-                close: function () {
-                    $(this).remove();
-                }
-            });
+                .append(data.message)
+                .dialog({
+                    title: PMA_messages.strAddIndex,
+                    width: 450,
+                    minHeight: 250,
+                    open: function () {
+                        checkIndexName('index_frm');
+                        PMA_showHints($div);
+                        PMA_init_slider();
+                        $('#index_columns').find('td').each(function () {
+                            $(this).css('width', $(this).width() + 'px');
+                        });
+                        $('#index_columns').find('tbody').sortable({
+                            axis: 'y',
+                            containment: $('#index_columns').find('tbody'),
+                            tolerance: 'pointer'
+                        });
+                        // We dont need the slider at this moment.
+                        $(this).find('fieldset.tblFooters').remove();
+                    },
+                    modal: true,
+                    buttons: button_options,
+                    close: function () {
+                        $(this).remove();
+                    }
+                });
         }
     });
 }
@@ -426,8 +418,7 @@ function PMA_showAddIndexDialog(source_array, array_index, target_columns, col_i
  *
  * @return void
  */
-function PMA_indexTypeSelectionDialog(source_array, index_choice, col_index)
-{
+function PMA_indexTypeSelectionDialog (source_array, index_choice, col_index) {
     var $single_column_radio = $('<input type="radio" id="single_column" name="index_choice"' +
         ' checked="checked">' +
         '<label for="single_column">' + PMA_messages.strCreateSingleColumnIndex + '</label>');
@@ -447,7 +438,7 @@ function PMA_indexTypeSelectionDialog(source_array, index_choice, col_index)
     button_options[PMA_messages.strGo] = function () {
         if ($('#single_column').is(':checked')) {
             var index = {
-                'Key_name': (index_choice == 'primary' ? 'PRIMARY' : ''),
+                'Key_name': (index_choice === 'primary' ? 'PRIMARY' : ''),
                 'Index_choice': index_choice.toUpperCase()
             };
             PMA_showAddIndexDialog(source_array, (source_array.length), [col_index], col_index, index);
@@ -469,13 +460,13 @@ function PMA_indexTypeSelectionDialog(source_array, index_choice, col_index)
             var array_index = $('input[name="composite_with"]:checked').val();
             var source_length = source_array[array_index].columns.length;
             var target_columns = [];
-            for (var i=0; i<source_length; i++) {
+            for (var i = 0; i < source_length; i++) {
                 target_columns.push(source_array[array_index].columns[i].col_index);
             }
             target_columns.push(col_index);
 
             PMA_showAddIndexDialog(source_array, array_index, target_columns, col_index,
-             source_array[array_index]);
+                source_array[array_index]);
         }
 
         $(this).remove();
@@ -529,7 +520,7 @@ AJAX.registerTeardown('indexes.js', function () {
     $(document).off('click', '#preview_index_frm');
     $(document).off('change', '#select_index_choice');
     $(document).off('click', 'a.drop_primary_key_index_anchor.ajax');
-    $(document).off('click', "#table_index tbody tr td.edit_index.ajax, #indexes .add_index.ajax");
+    $(document).off('click', '#table_index tbody tr td.edit_index.ajax, #index_div .add_index.ajax');
     $(document).off('click', '#index_frm input[type=submit]');
     $('body').off('change', 'select[name*="field_key"]');
     $(document).off('click', '.show_index_dialog');
@@ -558,15 +549,16 @@ AJAX.registerOnload('indexes.js', function () {
         PMA_hideShowConnection($engine_selector);
     }
 
-    var $form = $("#index_frm");
+    var $form = $('#index_frm');
     if ($form.length > 0) {
         showIndexEditDialog($form);
     }
 
     $(document).on('click', '#save_index_frm', function (event) {
         event.preventDefault();
-        var $form = $("#index_frm");
-        var submitData = $form.serialize() + '&do_save_data=1&ajax_request=true&ajax_page_request=true';
+        var $form = $('#index_frm');
+        var argsep = PMA_commonParams.get('arg_separator');
+        var submitData = $form.serialize() + argsep + 'do_save_data=1' + argsep + 'ajax_request=true' + argsep + 'ajax_page_request=true';
         var $msgbox = PMA_ajaxShowMessage(PMA_messages.strProcessingRequest);
         AJAX.source = $form;
         $.post($form.attr('action'), submitData, AJAX.responseHandler);
@@ -580,7 +572,7 @@ AJAX.registerOnload('indexes.js', function () {
     $(document).on('change', '#select_index_choice', function (event) {
         event.preventDefault();
         checkIndexType();
-        checkIndexName("index_frm");
+        checkIndexName('index_frm');
     });
 
     /**
@@ -611,14 +603,13 @@ AJAX.registerOnload('indexes.js', function () {
             var $msg = PMA_ajaxShowMessage(PMA_messages.strDroppingPrimaryKeyIndex, false);
             var params = {
                 'is_js_confirmed': 1,
-                'ajax_request': true,
-                'token' : PMA_commonParams.get('token')
+                'ajax_request': true
             };
             $.post(url, params, function (data) {
                 if (typeof data !== 'undefined' && data.success === true) {
                     PMA_ajaxRemoveMessage($msg);
                     var $table_ref = $rows_to_hide.closest('table');
-                    if ($rows_to_hide.length == $table_ref.find('tbody > tr').length) {
+                    if ($rows_to_hide.length === $table_ref.find('tbody > tr').length) {
                         // We are about to remove all rows from the table
                         $table_ref.hide('medium', function () {
                             $('div.no_indexes_defined').show('medium');
@@ -627,7 +618,7 @@ AJAX.registerOnload('indexes.js', function () {
                         $table_ref.siblings('div.notice').hide('medium');
                     } else {
                         // We are removing some of the rows only
-                        $rows_to_hide.hide("medium", function () {
+                        $rows_to_hide.hide('medium', function () {
                             $(this).remove();
                         });
                     }
@@ -641,23 +632,24 @@ AJAX.registerOnload('indexes.js', function () {
                         PMA_highlightSQL($('#page_content'));
                     }
                     PMA_commonActions.refreshMain(false, function () {
-                        $("a.ajax[href^=#indexes]").click();
+                        $('a.ajax[href^=#indexes]').click();
                     });
                     PMA_reloadNavigation();
                 } else {
-                    PMA_ajaxShowMessage(PMA_messages.strErrorProcessingRequest + " : " + data.error, false);
+                    PMA_ajaxShowMessage(PMA_messages.strErrorProcessingRequest + ' : ' + data.error, false);
                 }
             }); // end $.post()
         }); // end $.PMA_confirm()
-    }); //end Drop Primary Key/Index
+    }); // end Drop Primary Key/Index
 
     /**
      *Ajax event handler for index edit
     **/
-    $(document).on('click', "#table_index tbody tr td.edit_index.ajax, #indexes .add_index.ajax", function (event) {
+    $(document).on('click', '#table_index tbody tr td.edit_index.ajax, #index_div .add_index.ajax', function (event) {
         event.preventDefault();
-        var url, title;
-        if ($(this).find("a").length === 0) {
+        var url;
+        var title;
+        if ($(this).find('a').length === 0) {
             // Add index
             var valid = checkFormElementInRange(
                 $(this).closest('form')[0],
@@ -671,17 +663,17 @@ AJAX.registerOnload('indexes.js', function () {
             title = PMA_messages.strAddIndex;
         } else {
             // Edit index
-            url = $(this).find("a").attr("href");
-            if (url.substring(0, 16) == "tbl_indexes.php?") {
+            url = $(this).find('a').attr('href');
+            if (url.substring(0, 16) === 'tbl_indexes.php?') {
                 url = url.substring(16, url.length);
             }
             title = PMA_messages.strEditIndex;
         }
-        url += "&ajax_request=true";
+        url += PMA_commonParams.get('arg_separator') + 'ajax_request=true';
         indexEditorDialog(url, title, function () {
             // refresh the page using ajax
             PMA_commonActions.refreshMain(false, function () {
-                $("a.ajax[href^=#indexes]").click();
+                $('a.ajax[href^=#indexes]').click();
             });
         });
     });
@@ -700,35 +692,35 @@ AJAX.registerOnload('indexes.js', function () {
         // Array containing corresponding indexes.
         var source_array = null;
 
-        if (index_choice == 'none') {
+        if (index_choice === 'none') {
             PMA_removeColumnFromIndex(col_index);
             return false;
         }
 
         // Select a source array.
         source_array = PMA_getIndexArray(index_choice);
-        if (source_array == null) {
+        if (source_array === null) {
             return;
         }
 
         if (source_array.length === 0) {
             var index = {
-                'Key_name': (index_choice == 'primary' ? 'PRIMARY' : ''),
+                'Key_name': (index_choice === 'primary' ? 'PRIMARY' : ''),
                 'Index_choice': index_choice.toUpperCase()
             };
             PMA_showAddIndexDialog(source_array, 0, [col_index], col_index, index);
         } else {
-            if (index_choice == 'primary') {
+            if (index_choice === 'primary') {
                 var array_index = 0;
                 var source_length = source_array[array_index].columns.length;
                 var target_columns = [];
-                for (var i=0; i<source_length; i++) {
+                for (var i = 0; i < source_length; i++) {
                     target_columns.push(source_array[array_index].columns[i].col_index);
                 }
                 target_columns.push(col_index);
 
                 PMA_showAddIndexDialog(source_array, array_index, target_columns, col_index,
-                 source_array[array_index]);
+                    source_array[array_index]);
             } else {
                 // If there are multiple columns selected for an index, show advanced dialog.
                 PMA_indexTypeSelectionDialog(source_array, index_choice, col_index);
@@ -756,5 +748,11 @@ AJAX.registerOnload('indexes.js', function () {
         }
 
         PMA_showAddIndexDialog(source_array, array_index, target_columns, -1, source_array[array_index]);
-    })
+    });
+
+    $('#index_frm').on('submit', function () {
+        if (typeof(this.elements['index[Key_name]'].disabled) !== 'undefined') {
+            this.elements['index[Key_name]'].disabled = false;
+        }
+    });
 });
