@@ -6,20 +6,19 @@
  * @package PhpMyAdmin
  */
 
-use PMA\libraries\Response;
-use PMA\libraries\ServerStatusData;
+use PhpMyAdmin\Response;
+use PhpMyAdmin\Server\Status\Data;
+use PhpMyAdmin\Server\Status\Processes;
 
 require_once 'libraries/common.inc.php';
 require_once 'libraries/server_common.inc.php';
-require_once 'libraries/server_status_processes.lib.php';
 
 /**
  * Replication library
  */
 require_once 'libraries/replication.inc.php';
-require_once 'libraries/replication_gui.lib.php';
 
-$ServerStatusData = new ServerStatusData();
+$serverStatusData = new Data();
 $response = Response::getInstance();
 
 /**
@@ -30,12 +29,12 @@ if ($response->isAjax() && !empty($_REQUEST['kill'])) {
     $kill = intval($_REQUEST['kill']);
     $query = $GLOBALS['dbi']->getKillQuery($kill);
     if ($GLOBALS['dbi']->tryQuery($query)) {
-        $message = PMA\libraries\Message::success(
+        $message = PhpMyAdmin\Message::success(
             __('Thread %s was successfully killed.')
         );
         $response->setRequestStatus(true);
     } else {
-        $message = PMA\libraries\Message::error(
+        $message = PhpMyAdmin\Message::error(
             __(
                 'phpMyAdmin was unable to kill thread %s.'
                 . ' It probably has already been closed.'
@@ -47,17 +46,17 @@ if ($response->isAjax() && !empty($_REQUEST['kill'])) {
     $response->addJSON('message', $message);
 } elseif ($response->isAjax() && !empty($_REQUEST['refresh'])) {
     // Only sends the process list table
-    $response->addHTML(PMA_getHtmlForServerProcessList());
+    $response->addHTML(Processes::getHtmlForServerProcesslist());
 } else {
     // Load the full page
     $header   = $response->getHeader();
     $scripts  = $header->getScripts();
     $scripts->addFile('server_status_processes.js');
     $response->addHTML('<div>');
-    $response->addHTML($ServerStatusData->getMenuHtml());
-    $response->addHTML(PMA_getHtmlForProcessListFilter());
-    $response->addHTML(PMA_getHtmlForServerProcesslist());
-    $response->addHTML(PMA_getHtmlForProcessListAutoRefresh());
+    $response->addHTML($serverStatusData->getMenuHtml());
+    $response->addHTML(Processes::getHtmlForProcessListFilter());
+    $response->addHTML(Processes::getHtmlForServerProcesslist());
+    $response->addHTML(Processes::getHtmlForProcessListAutoRefresh());
     $response->addHTML('</div>');
 }
 exit;
