@@ -8,15 +8,14 @@
  */
 
 // unplanned execution path
-if (! defined('PMA_MINIMUM_COMMON') && ! defined('TESTSUITE')) {
+if (! defined('PHPMYADMIN') && ! defined('TESTSUITE')) {
     exit();
 }
 ?>
 /******************************************************************************/
-
 /* general tags */
 html {
-    font-size: <?php echo $_SESSION['PMA_Theme']->getFontSize(); ?>
+    font-size: <?php echo $theme->getFontSize(); ?>
 }
 
 input,
@@ -45,6 +44,22 @@ body#loginform {
     margin: 0 .5em;
 }
 
+.desktop50 {
+    width: 50%;
+}
+
+.all100 {
+    width: 100%;
+}
+
+.all85{
+    width: 85%;
+}
+
+.auth_config_tbl{
+    margin: 0 auto;
+}
+
 <?php if (! empty($GLOBALS['cfg']['FontFamilyFixed'])) : ?>
     textarea,
     tt,
@@ -132,13 +147,13 @@ button.mult_submit:focus,
     -moz-border-radius: 5px;
     -webkit-border-radius: 5px;
     border-radius: 5px;
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ffffff', 'e0e0e0'); ?>
+    <?php echo $theme->getCssGradient('ffffff', 'e0e0e0'); ?>
 }
 
 #initials_table a.active {
     border: 1px solid #666;
     box-shadow: 0 0 2px #999;
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('bbbbbb', 'ffffff'); ?>
+    <?php echo $theme->getCssGradient('bbbbbb', 'ffffff'); ?>
 }
 
 dfn {
@@ -154,7 +169,7 @@ th {
     font-weight: bold;
     color: <?php echo $GLOBALS['cfg']['ThColor']; ?>;
     background: #f3f3f3;
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ffffff', 'cccccc'); ?>
+    <?php echo $theme->getCssGradient('ffffff', 'cccccc'); ?>
 }
 
 a img {
@@ -283,7 +298,7 @@ input.button {
 
     text-shadow: 0 1px 0 #fff;
 
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('f8f8f8', 'd8d8d8'); ?>
+    <?php echo $theme->getCssGradient('f8f8f8', 'd8d8d8'); ?>
 }
 
 input[type=submit]:hover,
@@ -293,7 +308,7 @@ input[type=reset]:hover,
 input[name=submit_reset]:hover,
 input.button:hover {
     position: relative;
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('fff', 'ddd'); ?>
+    <?php echo $theme->getCssGradient('fff', 'ddd'); ?>
     cursor: pointer;
 }
 
@@ -304,7 +319,7 @@ input[type=reset]:active,
 input[name=submit_reset]:active,
 input.button:active {
     position: relative;
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('eee', 'ddd'); ?>
+    <?php echo $theme->getCssGradient('eee', 'ddd'); ?>
     box-shadow: 0 1px 6px -2px #333 inset;
     text-shadow: none;
 }
@@ -335,7 +350,7 @@ fieldset, .preview_sql {
     -moz-border-radius: 4px 4px 0 0;
     -webkit-border-radius: 4px 4px 0 0;
     border: #aaa solid 1px;
-    padding: 1.5em;
+    padding: 0.5em;
     background: #eee;
     text-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>1px 1px 2px #fff inset;
     -moz-box-shadow: <?php echo $GLOBALS['text_dir'] === 'rtl' ? '-' : ''; ?>1px 1px 2px #fff inset;
@@ -370,8 +385,7 @@ fieldset legend {
     margin: 1.5em;
 }
 
-/* buttons in some browsers (eg. Konqueror) are block elements,
-   this breaks design */
+/* buttons in some browsers (eg. Konqueror) are block elements, this breaks design */
 button {
     display: inline;
 }
@@ -379,13 +393,17 @@ button {
 table caption,
 table th,
 table td {
-    padding: .3em;
+    padding: .1em .3em;
     margin: .1em;
-    vertical-align: top;
+    vertical-align: middle;
     text-shadow: 0 1px 0 #fff;
 }
 
 /* 3.4 */
+.datatable{
+    table-layout: fixed;
+}
+
 table {
     border-collapse: collapse;
 }
@@ -423,7 +441,7 @@ select {
 }
 
 select[multiple] {
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ffffff', 'f2f2f2'); ?>
+    <?php echo $theme->getCssGradient('ffffff', 'f2f2f2'); ?>
 }
 
 /******************************************************************************/
@@ -539,50 +557,48 @@ button.mult_submit {
 }
 
 /* odd items 1,3,5,7,... */
-table tr.odd th,
-.odd {
+table tbody:first-of-type tr:nth-child(odd),
+table tbody:first-of-type tr:nth-child(odd) th,
+#table_index tbody:nth-of-type(odd) tr,
+#table_index tbody:nth-of-type(odd) th {
     background: #fff;
-    <?php echo $_SESSION['PMA_Theme']->getCssIEClearFilter(); ?>
 }
 
 /* even items 2,4,6,8,... */
-/* (tested on CRTs and ACLs) */
-table tr.even th,
-.even {
+table tbody:first-of-type tr:nth-child(even),
+table tbody:first-of-type tr:nth-child(even) th,
+#table_index tbody:nth-of-type(even) tr,
+#table_index tbody:nth-of-type(even) th {
     background: #DFDFDF;
-    <?php echo $_SESSION['PMA_Theme']->getCssIEClearFilter(); ?>
 }
 
-/* odd table rows 1,3,5,7,... */
-table tr.odd th,
-table tr.odd,
-table tr.even th,
-table tr.even {
+table tr th,
+table tr {
     text-align: <?php echo $left; ?>;
 }
 
 /* marked table rows */
 td.marked:not(.nomarker),
 table tr.marked:not(.nomarker) td,
-table tr.marked:not(.nomarker) th,
+table tbody:first-of-type tr.marked:not(.nomarker) th,
 table tr.marked:not(.nomarker) {
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ced6df', 'b6c6d7'); ?>
+    <?php echo $theme->getCssGradient('ced6df', 'b6c6d7'); ?>
     color: <?php echo $GLOBALS['cfg']['BrowseMarkerColor']; ?>;
 }
 
 /* hovered items */
-.odd:not(.nopointer):hover,
-.even:not(.nopointer):hover,
+table tbody:first-of-type tr:not(.nopointer):hover,
+table tbody:first-of-type tr:not(.nopointer):hover th,
 .hover:not(.nopointer) {
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ced6df', 'b6c6d7'); ?>
+    <?php echo $theme->getCssGradient('ced6df', 'b6c6d7'); ?>
     color: <?php echo $GLOBALS['cfg']['BrowsePointerColor']; ?>;
 }
 
 /* hovered table rows */
-table tr.odd:not(.nopointer):hover th,
-table tr.even:not(.nopointer):hover th,
+#table_index tbody:hover tr,
+#table_index tbody:hover th,
 table tr.hover:not(.nopointer) th {
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ced6df', 'b6c6d7'); ?>
+    <?php echo $theme->getCssGradient('ced6df', 'b6c6d7'); ?>
     color: <?php echo $GLOBALS['cfg']['BrowsePointerColor']; ?>;
 }
 
@@ -619,7 +635,7 @@ tr:last-child td.condition {
  */
 td.null {
     font-style: italic;
-    text-align: <?php echo $right; ?>;
+    color: #7d7d7d;
 }
 
 table .valueHeader {
@@ -686,6 +702,7 @@ img.lightbulb {
 
 /* no extra space in table cells */
 td .icon {
+    image-rendering: pixelated;
     margin: 0;
 }
 
@@ -793,6 +810,10 @@ fieldset.confirmation legend {
 
 /* end messageboxes */
 
+.new_central_col{
+    width: 100%;
+}
+
 .tblcomment {
     font-size: 70%;
     font-weight: normal;
@@ -900,6 +921,40 @@ form.login select {
     font-size: 70%;
 }
 
+.cfg_dbg_demo{
+    margin: 0.5em 1em 0.5em 1em;
+}
+
+.central_columns_navigation{
+    padding:1.5% 0em !important;
+}
+
+.central_columns_add_column{
+    display:inline-block;
+    margin-left:1%;
+    max-width:50%
+}
+
+.message_errors_found{
+    margin-top: 20px;
+}
+
+.repl_gui_skip_err_cnt{
+    width: 30px;
+}
+
+.font_weight_bold{
+    font-weight: bold;
+}
+
+.color_gray{
+    color: gray;
+}
+
+.pma_sliding_message{
+    display: inline-block;
+}
+
 /******************************************************************************/
 /* specific elements */
 
@@ -919,7 +974,6 @@ ul.tabs {
     list-style-type: none;
     margin: 0;
     padding: 0;
-
 }
 
 ul#topmenu2 {
@@ -942,10 +996,14 @@ ul#topmenu2 li {
 }
 
 .menucontainer {
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ffffff', 'dcdcdc'); ?>
+    <?php echo $theme->getCssGradient('ffffff', 'dcdcdc'); ?>
     border-top: 1px solid #aaa;
 }
 
+.scrollindicator {
+    display: none;
+}
+
 /* default tab styles */
 .tabactive {
     background: #fff !important;
@@ -965,6 +1023,9 @@ ul#topmenu2 a {
 
 }
 
+span.caution {
+    color: #FF0000;
+}
 fieldset.caution a {
     color: #FF0000;
 }
@@ -1125,7 +1186,8 @@ div#tablestatistics table {
     padding: .3em .9em;
     padding-<?php echo $left; ?>: 2.2em;
     text-shadow: 0 1px 0 #000;
-    width: 10000px;
+    max-width: 100%;
+    max-height: 16px;
     overflow: hidden;
 }
 
@@ -1288,7 +1350,7 @@ h3#serverstatusqueries span {
 
 /* Also used for the variables page */
 fieldset#tableFilter {
-    margin-bottom: 1em;
+    padding: 0.1em 1em;
 }
 
 div#serverStatusTabs {
@@ -1303,7 +1365,7 @@ div#serverstatusquerieschart {
     float: <?php echo $left; ?>;
     width: 500px;
     height: 350px;
-    padding-<?php echo $left; ?>: 30px;
+    margin-<?php echo $right;?>: 50px;
 }
 
 table#serverstatusqueriesdetails,
@@ -1431,33 +1493,23 @@ div#queryAnalyzerDialog table.queryNums {
 
 /* server variables */
 #serverVariables {
-    table-layout: fixed;
     width: 100%;
 }
 #serverVariables .var-row > td {
-    white-space: nowrap;
-    overflow: hidden;
-    text-overflow: ellipsis;
     line-height: 2em;
 }
 #serverVariables .var-header {
     color: <?php echo $GLOBALS['cfg']['ThColor']; ?>;
     background: #f3f3f3;
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ffffff', 'cccccc'); ?>
+    <?php echo $theme->getCssGradient('ffffff', 'cccccc'); ?>
     font-weight: bold;
-}
-#serverVariables .var-header {
     text-align: <?php echo $left; ?>;
 }
 #serverVariables .var-row {
     padding: 0.5em;
     min-height: 18px;
 }
-#serverVariables .var-action {
-    width: 120px;
-}
 #serverVariables .var-name {
-    float: <?php echo $left; ?>;
     font-weight: bold;
 }
 #serverVariables .var-name.session {
@@ -1465,7 +1517,6 @@ div#queryAnalyzerDialog table.queryNums {
     font-style: italic;
 }
 #serverVariables .var-value {
-    width: 50%;
     float: <?php echo $right; ?>;
     text-align: <?php echo $right; ?>;
 }
@@ -1477,7 +1528,6 @@ div#queryAnalyzerDialog table.queryNums {
 /* server variables editor */
 #serverVariables .editLink {
     padding-<?php echo $right; ?>: 1em;
-    float: <?php echo $left; ?>;
     font-family: sans-serif;
 }
 #serverVariables .serverVariableEditor {
@@ -1499,7 +1549,6 @@ div#queryAnalyzerDialog table.queryNums {
     padding-<?php echo $right; ?>: 1em;
 }
 #serverVariables .serverVariableEditor a {
-    float: <?php echo $right; ?>;
     margin: 0 0.5em;
     line-height: 2em;
 }
@@ -1574,6 +1623,7 @@ div#profilingchart {
     font-size: 1.7em;
 }
 #sectionlinks {
+    margin-bottom: 15px;
     padding: 16px;
     background: #f3f3f3;
     border: 1px solid #aaa;
@@ -1600,12 +1650,12 @@ a.button {
     border-radius: 20px;
     -webkit-border-radius: 20px;
     -moz-border-radius: 20px;
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('f8f8f8', 'd8d8d8'); ?>
+    <?php echo $theme->getCssGradient('f8f8f8', 'd8d8d8'); ?>
 }
 #sectionlinks a:hover,
 .buttonlinks a:hover,
 a.button:hover {
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ffffff', 'dddddd'); ?>
+    <?php echo $theme->getCssGradient('ffffff', 'dddddd'); ?>
 }
 
 div#sqlquerycontainer {
@@ -1649,7 +1699,7 @@ div#queryboxcontainer div#bookmarkoptions {
 
 /* main page */
 #maincontainer {
-    /* background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('logo_right.png');?>); */
+    /* background-image: url(<?php echo $theme->getImgPath('logo_right.png');?>); */
     /* background-position: <?php echo $right; ?> bottom; */
     /* background-repeat: no-repeat; */
 }
@@ -1744,31 +1794,6 @@ li.no_bullets {
     width: 35%;
 }
 
-.operations_half_width {
-    width: 48%;
-    float: <?php echo $left; ?>;
-}
-.operations_half_width input[type=text],
-.operations_half_width input[type=password],
-.operations_half_width input[type=number],
-.operations_half_width select {
-    width: 95%;
-}
-.operations_half_width input[type=text].halfWidth,
-.operations_half_width input[type=password].halfWidth,
-.operations_half_width input[type=number].halfWidth,
-.operations_half_width select.halfWidth {
-    width: 40%;
-}
-.operations_half_width ul {
-    list-style-type: none;
-    padding: 0;
-}
-.operations_full_width {
-    width: 100%;
-    clear: both;
-}
-
 #qbe_div_table_list {
     float: <?php echo $left; ?>;
 }
@@ -1786,6 +1811,16 @@ label.desc sup {
     position: absolute;
 }
 
+code.php {
+    display: block;
+    padding-left: 1em;
+    margin-top: 0;
+    margin-bottom: 0;
+    max-height: 10em;
+    overflow: auto;
+    direction: ltr;
+}
+
 code.sql,
 div.sqlvalidate {
     display: block;
@@ -1799,6 +1834,7 @@ div.sqlvalidate {
 
 .result_query div.sqlOuter {
     background: <?php echo $GLOBALS['cfg']['BgOne']; ?>;
+    text-align: <?php echo $left; ?>;
 }
 
 .result_query .success, .result_query .error {
@@ -1962,7 +1998,7 @@ select.invalid_value,
     display: inline;
     left: 0;
     right: 0;
-    background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('ajax_clock_small.gif');?>);
+    background-image: url(<?php echo $theme->getImgPath('ajax_clock_small.gif');?>);
     background-repeat: no-repeat;
     background-position: 2%;
     border: 1px solid #e2b709;
@@ -2013,6 +2049,10 @@ select.invalid_value,
     vertical-align: middle;
 }
 
+.exportoptions h2 {
+    word-wrap: break-word;
+}
+
 .exportoptions h3,
 .importoptions h3 {
     border-bottom: 1px #999 solid;
@@ -2067,7 +2107,7 @@ select.invalid_value,
 
     text-shadow: 0 1px 0 #fff;
 
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('ffffff', 'cccccc'); ?>
+    <?php echo $theme->getCssGradient('ffffff', 'cccccc'); ?>
     cursor: pointer;
 }
 
@@ -2112,7 +2152,12 @@ select#table_select {
 .export_sub_options li {
     margin-bottom: 0;
 }
-
+#export_refresh_form {
+    margin-left: 20px;
+}
+#export_back_button {
+    display: inline;
+}
 #output_quick_export {
     display: none;
 }
@@ -2133,6 +2178,10 @@ input#input_import_file {
     margin: 5px 0 5px 0;
 }
 
+#filterText {
+    vertical-align: baseline;
+}
+
 #popup_background {
     display: none;
     position: fixed;
@@ -2176,9 +2225,9 @@ input#input_import_file {
 /**
  * Indexes
  */
-#index_frm .index_info input,
+#index_frm .index_info input[type="text"],
 #index_frm .index_info select {
-    width: 14em;
+    width: 100%;
     margin: 0;
     box-sizing: border-box;
     -ms-box-sizing: border-box;
@@ -2223,7 +2272,7 @@ table#index_columns {
 
 table#index_columns select {
     width: 85%;
-    float: right;
+    float: <?php echo $left; ?>;
 }
 
 #move_columns_dialog div {
@@ -2532,9 +2581,10 @@ fieldset .disabled-field td {
 .toggleButton .container {
     position: absolute;
 }
-.toggleButton .container td {
+.toggleButton .container td,
+.toggleButton .container tr {
     background-image: none;
-    background: none;
+    background: none !important;
 }
 .toggleButton .toggleOn {
     color: #fff;
@@ -2590,6 +2640,13 @@ fieldset .disabled-field td {
     border: 1px solid #aaa;
     float: <?php echo $right; ?>;
     overflow: hidden;
+    width: 450px;
+    height: 300px;
+}
+
+#openlayersmap{
+    width: 450px;
+    height: 300px;
 }
 
 .placeholderDrag {
@@ -2698,7 +2755,7 @@ fieldset .disabled-field td {
 }
 
 .cPointer {
-    background: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('col_pointer.png');?>);
+    background: url(<?php echo $theme->getImgPath('col_pointer.png');?>);
     height: 20px;
     margin-<?php echo $left; ?>: -5px;  /* must be minus half of its width */
     margin-top: -10px;
@@ -2731,7 +2788,7 @@ fieldset .disabled-field td {
 }
 
 .coldrop {
-    background: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('col_drop.png');?>);
+    background: url(<?php echo $theme->getImgPath('col_drop.png');?>);
     cursor: pointer;
     height: 16px;
     margin-<?php echo $left; ?>: .3em;
@@ -2796,7 +2853,7 @@ fieldset .disabled-field td {
     -webkit-border-radius: 5px;
     -moz-border-radius: 5px;
 
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('eeeeee', 'cccccc'); ?>
+    <?php echo $theme->getCssGradient('eeeeee', 'cccccc'); ?>
 }
 
 .navigation td {
@@ -2834,7 +2891,7 @@ fieldset .disabled-field td {
     cursor: pointer;
     text-shadow: none;
 
-    <?php echo $_SESSION['PMA_Theme']->getCssGradient('333333', '555555'); ?>
+    <?php echo $theme->getCssGradient('333333', '555555'); ?>
 }
 
 .navigation select {
@@ -2873,18 +2930,19 @@ fieldset .disabled-field td {
 }
 
 .cEdit .edit_box {
-    overflow: hidden;
+    overflow-x: hidden;
+    overflow-y: scroll;
     padding: 0;
     margin: 0;
 }
 
 .cEdit .edit_box_posting {
-    background: #FFF url(<?php echo $_SESSION['PMA_Theme']->getImgPath('ajax_clock_small.gif');?>) no-repeat right center;
+    background: #FFF url(<?php echo $theme->getImgPath('ajax_clock_small.gif');?>) no-repeat right center;
     padding-<?php echo $right; ?>: 1.5em;
 }
 
 .cEdit .edit_area_loading {
-    background: #FFF url(<?php echo $_SESSION['PMA_Theme']->getImgPath('ajax_clock_small.gif');?>) no-repeat center;
+    background: #FFF url(<?php echo $theme->getImgPath('ajax_clock_small.gif');?>) no-repeat center;
     height: 10em;
 }
 
@@ -2895,10 +2953,14 @@ fieldset .disabled-field td {
 }
 
 .saving_edited_data {
-    background: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('ajax_clock_small.gif');?>) no-repeat left;
+    background: url(<?php echo $theme->getImgPath('ajax_clock_small.gif');?>) no-repeat left;
     padding-<?php echo $left; ?>: 20px;
 }
 
+.relationalTable td {
+    vertical-align: top;
+}
+
 .relationalTable select {
     width: 125px;
     margin-right: 5px;
@@ -2928,6 +2990,10 @@ body .ui-widget {
     color: #235A81;
 }
 
+.ui-draggable {
+    z-index: 801;
+}
+
 /* over-riding jqplot-yaxis class */
 .jqplot-yaxis {
     left:0 !important;
@@ -2956,10 +3022,6 @@ div#page_content div#tableslistcontainer table.data {
     border-top: 0.1px solid #EEEEEE;
 }
 
-div#page_content form#db_search_form.ajax fieldset {
-    margin-top: -0.3em;
-}
-
 div#page_content div#tableslistcontainer, div#page_content div.notice, div#page_content div.result_query {
     margin-top: 1em;
 }
@@ -2972,19 +3034,8 @@ table.show_create td {
     border-right: 1px solid #bbb;
 }
 
-#alias_modal table th {
-    vertical-align: middle;
-    padding-left: 1em;
-}
-
-#alias_modal label.col-2 {
-    min-width: 20%;
-    display: inline-block;
-}
-
-#alias_modal select {
-    width: 25%;
-    margin-right: 2em;
+#alias_modal table {
+    width: 100%;
 }
 
 #alias_modal label {
@@ -3341,9 +3392,6 @@ html.ie7 #pma_console .query_input {
     min-height: initial;
     max-height: initial;
 }
-.firefox .cm-s-pma.CodeMirror {
-    font-size: 120%;
-}
 .cm-s-pma .CodeMirror-scroll {
     cursor: text;
 }
@@ -3474,7 +3522,7 @@ html.ie7 #pma_console .query_input {
 
 span.drag_icon {
     display: inline-block;
-    background-image: url('<?php echo $_SESSION['PMA_Theme']->getImgPath('s_sortable.png');?>');
+    background-image: url('<?php echo $theme->getImgPath('s_sortable.png');?>');
     background-position: center center;
     background-repeat: no-repeat;
     width: 1em;
@@ -3486,6 +3534,16 @@ span.drag_icon {
     margin-top: 1em;
 }
 
+meter[value="1"]::-webkit-meter-optimum-value {
+    background: linear-gradient(white 3%, #E32929 5%, transparent 10%, #E32929);
+}
+meter[value="2"]::-webkit-meter-optimum-value {
+    background: linear-gradient(white 3%, #FF6600 5%, transparent 10%, #FF6600);
+}
+meter[value="3"]::-webkit-meter-optimum-value {
+    background: linear-gradient(white 3%, #FFD700 5%, transparent 10%, #FFD700);
+}
+
 /* styles for sortable tables created with tablesorter jquery plugin */
 th.header {
     cursor: pointer;
@@ -3507,11 +3565,11 @@ th.header .sorticon {
 }
 
 th.headerSortUp .sorticon, th.headerSortDown:hover .sorticon {
-    background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_desc.png');?>);
+    background-image: url(<?php echo $theme->getImgPath('s_desc.png');?>);
 }
 
 th.headerSortDown .sorticon, th.headerSortUp:hover .sorticon {
-    background-image: url(<?php echo $_SESSION['PMA_Theme']->getImgPath('s_asc.png');?>);
+    background-image: url(<?php echo $theme->getImgPath('s_asc.png');?>);
 }
 /* end of styles of sortable tables */
 
@@ -3529,3 +3587,100 @@ body .ui-dialog .ui-dialog-buttonpane .ui-dialog-buttonset {
     float: <?php echo $right; ?>;
 }
 /* end of styles for jQuery-ui to support rtl languages */
+
+.responsivetable {
+    overflow-x: auto;
+}
+@media only screen and (max-width: 768px) {
+    /* For mobile phones: */
+    #main_pane_left {
+        width: 100%;
+    }
+
+    #main_pane_right {
+        padding-top: 0;
+        padding-<?php echo $left; ?>: 1px;
+        padding-<?php echo $right; ?>: 1px;
+    }
+
+    ul#topmenu,
+    ul.tabs {
+        display: flex;
+    }
+
+    .navigationbar {
+        display: inline-flex;
+        margin: 0 !important;
+        border-radius: 0 !important;
+        overflow: auto;
+    }
+
+    .scrollindicator {
+        padding: 5px;
+        cursor: pointer;
+        display: inline;
+    }
+
+    .responsivetable {
+        overflow-x: auto;
+    }
+
+    body#loginform div.container {
+        width: 100%;
+    }
+
+    .largescreenonly {
+        display: none;
+    }
+
+    .width100, .desktop50 {
+        width: 100%;
+    }
+
+    .width96 {
+        width: 96% !important;
+    }
+
+    #page_nav_icons {
+        display: none;
+    }
+
+    table#serverstatusconnections {
+        margin-left: 0;
+    }
+
+    #table_name_col_no {
+        top: 62px
+    }
+
+    .tdblock tr td {
+        display: block;
+    }
+
+    #table_columns {
+        margin-top: 60px;
+    }
+
+    #table_columns .tablesorter {
+        min-width: 100%;
+    }
+
+    .doubleFieldset fieldset {
+        width: 98%;
+    }
+
+    div#serverstatusquerieschart {
+        width: 100%;
+        height: 450px;
+    }
+
+    .ui-dialog {
+        margin: 1%;
+        width: 95% !important;
+    }
+}
+/* templates/database/designer */
+/* side menu */
+#name-panel {
+    overflow:hidden;
+}
